# This script is covered by the terms given in upcxx/LICENSE.txt
# The point of this script is to place compilers in your $PATH.
# If you're using Docker or self-install, you can probably skip this script.
echo Adding compilers to your PATH...
unset host
set today=`date '+%D'`
#TESTING: set today='07/26/23'
if ($?NERSC_HOST) then
  if ($NERSC_HOST == perlmutter) then
    echo "Host identified as NERSC Perlmutter"
    set host=perlmutter
    set defacct=`sacctmgr -p -n show user name=$USER | cut -d\| -f2`
    if ($?) then
      unset defacct
    endif

    which module >& /dev/null
    if ( $? ) then
      source /etc/profile.d/zz-cray-pe.csh
    endif

    setenv TMPDIR '/dev/shm'
    setenv SLURM_THREADS_PER_CORE 1
    ml -q unload upcxx upcxx-cuda
    ml -q PrgEnv-gnu cpu gcc/11.2.0
    ml contrib upcxx/2023.3.0
    setenv PMIRUN_CMD 'srun -K0 -W60 %V -n %N -- %C'
    unsetenv UPCXX_INSTALL
    ml opencoarrays
    ml chapel cray-pmi
    setenv CHPL_RT_MAX_HEAP_SIZE "16GB"
    setenv CHPL_LAUNCHER_MEM unset

    if ($today =~ '07/2[345]/23') then
      echo "WARNING: TESTING pre-reservation logic"
      setenv SLURM_CONSTRAINT cpu
      unsetenv SLURM_RESERVATION
    endif

    # Reservation for CPU-only nodes July 26 and 27, 2023
    if ($today =~ '07/2[67]/23') then
      echo "Event identified as CUF23"
      if (! $?SLURM_CONSTRAINT) then
        setenv SLURM_CONSTRAINT cpu
      else if ($SLURM_CONSTRAINT != cpu) then
        echo "WARNING: Refusing to set SLURM_CONSTRAINT='cpu'."
        echo "         If the current setting SLURM_CONSTRAINT='$SLURM_CONSTRAINT' is not correct,"
        echo "         then you should manually set it as appropriate."
      endif
      if (! $?SLURM_ACCOUNT) then
        setenv SLURM_ACCOUNT ntrain7
      else if ($SLURM_ACCOUNT != ntrain7) then
        echo "WARNING: Refusing to set SLURM_ACCOUNT='ntrain7'."
        echo "         If the current setting SLURM_ACCOUNT='$SLURM_ACCOUNT' is not correct,"
        echo "         then you should manually set it as appropriate."
      endif
    endif
    if ($today =~ '07/26/23') then
      if (! $?SLURM_RESERVATION) then
        setenv SLURM_RESERVATION cuf23_day1
      else if ($SLURM_RESERVATION != cuf23_day1) then
        echo "WARNING: Refusing to set SLURM_RESERVATION='cuf23_day1'."
        echo "         If the current setting SLURM_RESERVATION='$SLURM_RESERVATION' is not correct,"
        echo "         then you should manually set it as appropriate."
      endif
    else if ($today =~ '07/27/23') then
      if (! $?SLURM_RESERVATION) then
        setenv SLURM_RESERVATION cuf23_day2
      else if ($SLURM_RESERVATION == cuf23_day1) then
        setenv SLURM_RESERVATION cuf23_day2
      else if ($SLURM_RESERVATION != cuf23_day2) then
        echo "WARNING: Refusing to set SLURM_RESERVATION='cuf23_day2'."
        echo "         If the current setting SLURM_RESERVATION='$SLURM_RESERVATION' is not correct,"
        echo "         then you should manually set it as appropriate."
      endif
    endif
    if ($?SLURM_RESERVATION) then
      setenv SALLOC_RESERVATION $SLURM_RESERVATION
    endif

    # Always need a default time limit
    if (! $?SLURM_TIMELIMIT) then
      setenv SLURM_TIMELIMIT '00:10:00'
    else if ($SLURM_TIMELIMIT != '00:10:00') then
      echo "WARNING: Refusing to set SLURM_TIMELIMIT='00:10:00'."
      echo "         If the current setting SLURM_TIMELIMIT='$SLURM_TIMELIMIT' is not correct,"
      echo "         then you should manually set it as appropriate."
    endif

    # Always need a default account
    if (! $?SLURM_ACCOUNT && $?defacct) then
      echo "WARNING: setting SLURM_ACCOUNT='$defacct'"
      echo '         If this is not the correct account to charge,'
      echo '         then you should manually set it as appropriate.'
      setenv SLURM_ACCOUNT "$defacct"
    endif
    if (! $?SLURM_ACCOUNT) then
      echo 'WARNING: The environment variable SLURM_ACCOUNT is unset or empty.'
      echo '         To launch applications as described in the tutorial, one must'
      echo '         set SLURM_ACCOUNT to an appropriate NERSC project id.'
      echo '         example: `export SLURM_ACCOUNT=m9999`'
      echo '         The `iris` command can be use to determine your project membership.'
    else
      setenv SALLOC_ACCOUNT $SLURM_ACCOUNT
    endif
  endif
else if ($?LMOD_SYSTEM_NAME) then
  if ($LMOD_SYSTEM_NAME == frontier) then
    echo "Host identified as OLCF Frontier"
    set host=frontier
    set defacct=`sacctmgr -p -n show user name=$USER | cut -d\| -f2`
    if ($?) then
      unset defacct
    endif

    setenv TMPDIR '/dev/shm'
    ml -q PrgEnv-gnu gcc/11.2.0 cray-pmi
    ml -q ums ums014 upcxx/2023.3.0
    unsetenv UPCXX_INSTALL
    ml opencoarrays
    ml chapel-cuf23 cray-pmi
    setenv CHPL_RT_MAX_HEAP_SIZE "16GB"
    setenv CHPL_LAUNCHER_MEM unset
    setenv CHPL_LAUNCHER_CORES_PER_LOCALE 56

    if ($today =~ '07/2[345]/23') then
      echo "WARNING: TESTING pre-reservation logic"
      unsetenv SLURM_RESERVATION
    endif

    # Reservation for July 26 and 27, 2023
    if ($today =~ '07/2[67]/23') then
      echo "Event identified as CUF23"
      if (! $?SLURM_RESERVATION) then
        setenv SLURM_RESERVATION pgas_training
      else if ($SLURM_RESERVATION != pgas_training) then
        echo "WARNING: Refusing to set SLURM_RESERVATION='pgas_training'."
        echo "         If the current setting SLURM_RESERVATION='$SLURM_RESERVATION' is not correct,"
        echo "         then you should manually set it as appropriate."
      endif
    endif
    if ($?SLURM_RESERVATION) then
      setenv SALLOC_RESERVATION $SLURM_RESERVATION
    endif

    # Always need a default time limit
    if (! $?SLURM_TIMELIMIT) then
      setenv SLURM_TIMELIMIT '00:10:00'
    else if ($SLURM_TIMELIMIT != '00:10:00') then
      echo "WARNING: Refusing to set SLURM_TIMELIMIT='00:10:00'."
      echo "         If the current setting SLURM_TIMELIMIT='$SLURM_TIMELIMIT' is not correct,"
      echo "         then you should manually set it as appropriate."
    endif

    # Always need a default account
    if (! $?SLURM_ACCOUNT && $?defacct) then
      echo "WARNING: setting SLURM_ACCOUNT='$defacct'"
      echo '         If this is not the correct account to charge,'
      echo '         then you should manually set it as appropriate.'
      setenv SLURM_ACCOUNT "$defacct"
    endif
    if (! $?SLURM_ACCOUNT) then
      echo 'WARNING: The environment variable SLURM_ACCOUNT is unset or empty.'
      echo '         To launch applications as described in the tutorial, one must'
      echo '         set SLURM_ACCOUNT to an appropriate OLCF project id.'
      echo '         example: `export SLURM_ACCOUNT=ABC123`'
      echo '         The `showusage` command can be use to determine your project membership.'
    else
      setenv SALLOC_ACCOUNT $SLURM_ACCOUNT
    endif
  endif
else if ( `id -un` == 'tutorial' ) then
  which aws >& /dev/null
  if (! $?) then
    echo "Host identified as AWS"
    set host=aws
  endif
endif
if ( ! $?host ) then
  echo 'This SOURCE_ME.csh script did not recognize your host.'
endif
foreach x ( ftdetect syntax )
  set dir=".vim/$x"
  set file="$dir/chpl.vim"
  if ( ! -e ~/$file ) then
    echo "Creating ~/$file for Chapel syntax highlighting"
    mkdir -p ~/$dir && cp chapel/$file ~/$dir/
  endif
end
set found=''
set missing=''
foreach tool ( upcxx chpl caf )
  which $tool >& /dev/null
  if ( $? ) then
    set missing="$missing $tool"
  else
    set found="$found $tool"
  endif
end
if ($missing == "") then
  echo 'Congratulations, the required tools are in your $PATH.'
else
  echo 'WARNING: The following tool(s) were found in your $PATH:'
  echo "           $found"
  echo '         but the following were NOT found:'
  echo "           $missing"
  echo '         If you need the missing tool(s), then you will need '
  echo '         to manually add their locations to your $PATH.'
endif

echo
echo "For UPC++ examples: cd upcxx  ;  more README.md"
echo "For Chapel examples: cd chapel ; more README.md"
echo "For Fortran examples: cd fortran ; more README.md"
echo
